@@ -500,7 +500,7 @@ applet_fill_cb (PanelApplet *applet,
 			G_CALLBACK (menuitem_destroy_cb), adata);
       g_signal_connect (menuitem, "activate",
 			G_CALLBACK (user_item_activate_cb), adata);
-      gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), menuitem);
+      gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), menuitem);
       adata->items = g_slist_prepend (adata->items, menuitem);
 
       if (active_only)
@@ -525,13 +525,13 @@ applet_fill_cb (PanelApplet *applet,
 		    G_CALLBACK (manager_user_added_cb), adata);
 
   adata->separator_item = gtk_separator_menu_item_new ();
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), adata->separator_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), adata->separator_item);
   adata->items = g_slist_prepend (adata->items, adata->separator_item);
 
   adata->login_screen_item = gtk_image_menu_item_new_with_label (_("Other"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_screen_item),
 				 gtk_image_new ());
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu),
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu),
 			  adata->login_screen_item);
   g_signal_connect (adata->login_screen_item, "style-set",
 		    G_CALLBACK (menuitem_style_set_cb), adata);
@@ -544,7 +544,7 @@ applet_fill_cb (PanelApplet *applet,
   adata->login_window_item = gtk_image_menu_item_new_with_label (_("Login Window"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_window_item),
 				 gtk_image_new ());
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu),
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu),
 			  adata->login_window_item);
   g_signal_connect (adata->login_window_item, "style-set",
 		    G_CALLBACK (menuitem_style_set_cb), adata);
@@ -1136,7 +1136,7 @@ about_cb (BonoboUIComponent *ui_container,
        "GNU General Public License for more details."),
     N_("You should have received a copy of the GNU General Public License "
        "along with this program; if not, write to the Free Software "
-        "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"),
+        "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA "),
     NULL
   };
   gchar *license_i18n;
@@ -1243,7 +1243,7 @@ manager_user_added_cb (FusaManager *manager,
 		    G_CALLBACK (menuitem_destroy_cb), adata);
   g_signal_connect (menuitem, "activate",
 		    G_CALLBACK (user_item_activate_cb), adata);
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), menuitem);
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), menuitem);
   adata->items = g_slist_prepend (adata->items, menuitem);
 
   active_only = gconf_client_get_bool (adata->client, ACTIVE_ONLY_KEY, NULL);
